#
# Cookbook:: esh_nginx
# Resource:: php_fpm
#
# Copyright:: 2022, https://easyself.host
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

unified_mode true
property :proxy_pass, String, name_property: true
property :set_real_ip_from, String, required: true
default_action :setup

action :setup do
  proxy_pass = new_resource.proxy_pass
  set_real_ip_from = new_resource.set_real_ip_from

  apt_package %w(
    nginx
    php-curl
    php-fpm
    php-gd
    php-json
    php-ldap
    php-mbstring
    php-mysql
    php-pgsql
    php-sqlite3
    php-xml
    php-zip
  )

  template '/etc/nginx/sites-available/default' do
    source 'default_fpm.erb'
    cookbook 'esh_nginx'
    owner 'root'
    group 'root'
    mode '0644'
    variables proxy_pass: proxy_pass,
      set_real_ip_from: set_real_ip_from
    notifies :reload, 'service[nginx]', :immediately
    action :create
  end

  service 'nginx' do
    action :nothing
  end
end
